@@ -4,6 +4,7 @@
    Copyright 1997-2005  Douglas M. Bates <bates@stat.wisc.edu>,
 			Jose C. Pinheiro,
 			Saikat DebRoy
+   Copyright 2007-2013  The R Core Team
 
    This file is part of the nlme package for R and related languages
    and is made available under the terms of the GNU General Public
@@ -519,7 +520,7 @@ ARMA_corr(longint *p, longint *q, longint *maxlag, double *pars, double *psi,
     double *coef = Calloc(P * P, double), *src, *qraux = Calloc(P, double),
 	*work = Calloc(P * P, double), *work1;
 
-    if (!sqrt_eps) sqrt_eps = sqrt(DOUBLE_EPS);
+    if (sqrt_eps == 0.0) sqrt_eps = sqrt(DOUBLE_EPS);
     if ((maxPQ = ((*p > *q) ? *p : *q))) {
 	for(i = 0, src = coef; i < P; i++, src += Pp1) {
 	    crr[i] = 0;
