@@ -1,7 +1,8 @@
 /*
    header file for the nlme package
 
-   Copyright 1999-2001  Saikat DebRoy <saikat@stat.wisc.edu>
+   Copyright 1999-2001  Saikat DebRoy
+   Copyright 2007-2013  The R Core Team
 
    This file is part of the nlme package for S and related languages
    and is made available under the terms of the GNU General Public
@@ -21,9 +22,11 @@
 */
 
 #ifndef NLME_MATRIX_H
-#define NLME_MATRIC_H
+#define NLME_MATRIX_H
 #include "base.h"
-#include <R_ext/Applic.h>
+void F77_NAME(chol)(double *a, int *lda, int *n, double *v, int *info);
+int F77_NAME(rs)(int *nm, int *n, double *a, double *w,
+		 int *matz, double *z, double *fv1, double *fv2, int *ierr);
 #include <R_ext/Linpack.h>
 
 typedef struct QR_struct {
