@@ -1,8 +1,9 @@
 /*
    header file for the nlme package
 
-   Copyright 1999-2001 Saikat DebRoy <saikat@stat.wisc.edu>,
+   Copyright 1999-2001 Saikat DebRoy,
 		       Douglas Bates <bates@stat.wisc.edu>
+   Copyright 2007-2013  The R Core Team
 
    This file is part of the nlme package for R and related languages
    and is made available under the terms of the GNU General Public
@@ -24,6 +25,7 @@
 #ifndef NLME_NLMEFIT_H
 #define NLME_NLMEFIT_H
 #include "base.h"
+#include <R_ext/Applic.h> // for nlm internals
 
 typedef struct dim_struct {
   longint
@@ -49,11 +51,12 @@ typedef struct state_struct {
   double *ZXy;
   longint *pdClass,
     *RML;
+  double	*sigma; // 17-11-2015; Fixed sigma patch; E van Willigen; Quantitative Solutions
 } *statePTR;
 
 extern dimPTR dims(longint *);
 extern dimPTR dimS(SEXP);
-extern size_t count_DmHalf_pars(dimPTR, longint *);
+extern int count_DmHalf_pars(dimPTR, longint *);
 extern double * generate_theta(double *, dimPTR, longint *, double *);
 extern double * generate_DmHalf(double *, dimPTR, longint *, double *);
 extern void dimFree(dimPTR);
@@ -62,24 +65,24 @@ extern void mixed_fcn(longint, double *, double *, void *);
 extern void mixed_grad(longint, double *, double *, void *);
 extern void internal_decomp(dimPTR, double *);
 extern void mixed_loglik(double *, longint *, double *, longint *,
-			 double *, double *);
+			 double *, double *, double *); // 17-11-2015; Fixed sigma patch; E van Willigen; Quantitative Solutions
 extern double internal_loglik(dimPTR, double *, double *, longint *,
-			      double *, double *);
+			      double *, double *, double *); // 17-11-2015; Fixed sigma patch; E van Willigen; Quantitative Solutions
 extern void mixed_estimate(double *, longint *, double *, longint *,
-			   double *, double *, longint *);
+			   double *, double *, longint *, double *); // 17-11-2015; Fixed sigma patch; E van Willigen; Quantitative Solutions
 extern void internal_estimate(dimPTR, double *);
 extern void mixed_EM(double *, longint *, double *, longint *,
-		     longint *, longint *, double *, double *, double *);
+		     longint *, longint *, double *, double *, double *, double *); // 17-11-2015; Fixed sigma patch; E van Willigen; Quantitative Solutions
 extern void internal_EM(dimPTR, double *, double *, int, longint *,
-			longint *, double *, double *, double *);
+			longint *, double *, double *, double *, double *); // 17-11-2015; Fixed sigma patch; E van Willigen; Quantitative Solutions
 extern void mixed_combined(double *, longint *, double *, longint *,
 			   longint *, longint *, double *, double *,
-			   double *, longint *);
+			   double *, longint *, double *); // 17-11-2015; Fixed sigma patch; E van Willigen; Quantitative Solutions
 extern void mixed_calcf(longint *, double *, longint *, double *,
 			longint *, double *, void (*)(void));
 extern void mixed_calcgh(longint *, double *, longint *, double *,
 			 double *, longint *, double *, void (*)(void));
-extern void gls_loglik(double *, longint *, double *, double *);
+extern void gls_loglik(double *, longint *, double *, double *, double *); // 17-11-2015; Fixed sigma patch; E van Willigen; Quantitative Solutions
 extern void gls_estimate(double *, longint *, double *, double *,
 			 double *, double *, longint *, longint *);
 
