@@ -1,7 +1,8 @@
 /*
    nls functions used in predict.nls
 
-   Copyright 1999 Saikat DebRoy <saikat@stat.wisc.edu>
+   Copyright 1999 Saikat DebRoy
+   Copyright 2007-2011  The R Core Team
 
    This file is part of the nlme package for S and related languages
    and is made available under the terms of the GNU General Public
@@ -17,7 +18,7 @@
    You should have received a copy of the GNU General Public License
    along with this program; if not, a copy is available at
    http://www.r-project.org/Licenses/
- 
+
 */
 #include "base.h"
 
@@ -29,9 +30,9 @@ static double
 est_delta(double *x, longint i)
 {
   double xx;
-  if(!sqrt_eps) sqrt_eps = sqrt(DOUBLE_EPS);
+  if(sqrt_eps == 0.0) sqrt_eps = sqrt(DOUBLE_EPS);
   if(!xlower) xlower = 100.*DOUBLE_XMIN;
-                                /* should sometime use the strategy of */
+				/* should sometime use the strategy of */
 				/* the grd routine in dmnf */
   xx = fabs(x[i]);
   if (xx < xlower) return sqrt_eps;
@@ -40,7 +41,7 @@ est_delta(double *x, longint i)
 
 void
 nls_diff_gradient(longint *pnpar, longint *pnobs, double *theta, double
-		  *base, double *gradient, longint *pneg aSEV) 
+		  *base, double *gradient, longint *pneg aSEV)
 {
   longint i, j, npar = *pnpar, nobs = *pnobs, neg = *pneg;
   double xx, *gcol, di;
@@ -57,4 +58,3 @@ nls_diff_gradient(longint *pnpar, longint *pnobs, double *theta, double
   }
 }
 #endif /* R_S_H */
-
